package com.mx.cneeds.server.user.service.impl;

import com.mx.cneeds.common.pager.PageUtils;
import com.mx.cneeds.common.pager.Query;
import com.mx.cneeds.server.dao.SysUserDao;
import com.mx.cneeds.server.entity.SysUserEntity;
import com.mx.cneeds.server.user.service.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.Map;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.transaction.annotation.Transactional;


@Service("sysUserService")
public class SysUserServiceImpl extends ServiceImpl<SysUserDao, SysUserEntity> implements SysUserService {

    @Autowired
    private SysUserFuncService sysUserFuncService;

    @Autowired
    private SysUserDeptService sysUserDeptService;

    @Autowired
    private SysUserRoleService sysUserRoleService;

    @Override
    public PageUtils queryPage(Map<String, Object> params) {
        IPage<SysUserEntity> page = this.page(
                new Query<SysUserEntity>().getPage(params),
                new QueryWrapper<SysUserEntity>()
        );

        return new PageUtils(page);
    }

    @Override
    public SysUserEntity queryUserByUsername(String username) {
        return getBaseMapper().selectOne(
                new QueryWrapper<SysUserEntity>()
                .eq("username",username));
    }


    @Override
    @Transactional(rollbackFor = Exception.class)
    public void deleteBatch(Long[] userIds) {
        //删除角色
        this.removeByIds(Arrays.asList(userIds));

        //删除用户与菜单关联
        sysUserFuncService.deleteBatch(userIds);

        //删除用户与部门关联
        sysUserDeptService.deleteBatch(userIds);

    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void saveUser(SysUserEntity user, List<Long> funcIdList, List<Long> deptIdList, Long roleId) {
        user.setCreateTime(new Date());
        this.save(user);


        //保存用户与角色关系
        sysUserRoleService.saveOrUpdate(user.getUserId(), roleId);

        //保存角色与菜单关系
        sysUserFuncService.saveOrUpdate(user.getUserId(), funcIdList);

        //保存角色与部门关系
        sysUserDeptService.saveOrUpdate(user.getUserId(), deptIdList);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void update(SysUserEntity user, List<Long> funcIdList, List<Long> deptIdList) {
        this.updateById(user);

        //更新用户与菜单关系
        sysUserFuncService.saveOrUpdate(user.getUserId(), funcIdList);

        //保存用户与部门关系
        sysUserDeptService.saveOrUpdate(user.getUserId(), deptIdList);
    }

}
